@@ -50,14 +50,8 @@ class GitHandler:
                 )
                 self.pull(rebase=True)
         except (CalledProcessError) as e:
-            if e.returncode == 128:
-                self.checkout(branch)  # caso checkout -b e branch gia' esistente
-            elif e.returncode == 1:
-                # caso checkout normale e branch non esistente
-                self.checkout(branch, new=True)
-            else:
-                logger.error(f"Errore eseguendo il comando: {e}")
-                sys.exit(-1)
+            logger.error(f"Errore eseguendo il comando: {e}")
+            sys.exit(-1)
 
     def commit(self, commit_message="", dummy=False):
         try:
